Learn R Programming

elgbd (version 0.9.0)

elgbd-package: elgbd: Empirical Likelihood for General Block Designs

Description

Performs hypothesis testing for general block designs with empirical likelihood. The core computational routines are implemented using the 'Eigen' 'C++' library and 'RcppEigen' interface, with 'OpenMP' for parallel computation. Details of the methods are given in Kim, MacEachern, and Peruggia (2023) tools:::Rd_expr_doi("10.1080/10485252.2023.2206919"). This work was supported by the U.S. National Science Foundation under Grants No. SES-1921523 and DMS-2015552.

Arguments

Author

Maintainer: Eunseop Kim markean@pm.me [copyright holder]

Other contributors:

  • Steven MacEachern [contributor, thesis advisor]

  • Mario Peruggia [contributor, thesis advisor]

References

Kim E, MacEachern SN, Peruggia M (2023). "Empirical likelihood for the analysis of experimental designs." Journal of Nonparametric Statistics, 35(4), 709--732. tools:::Rd_expr_doi("10.1080/10485252.2023.2206919").

See Also