A list containing the model fit and optimization results.
Arguments
formula
An object of class formula (or one that can be coerced to that class)
for a symbolic description of the model to be fitted. It must specify
the variables for response and treatment as response ~ treatment.
data
A data frame containing the variables in formula.
maxit
A single integer for the maximum number of iterations for optimization.
Defaults to 10000.
abstol
A single numeric for the absolute convergence tolerance for optimization.
Defaults to 1e-08.
References
Owen, A (1991).
"Empirical Likelihood for Linear Models."
The Annals of Statistics, 19(4), 1725--1747.
tools:::Rd_expr_doi("10.1214/aos/1176348368").